==========
asterisk_mbox
==========
asterisk_mbox is a client/server which provides an API to work with Asterisk voicemail mailboxes
This is the client library.  Install asterisk_mbox_server on the Asterisk server as well.

Capabilities
============

* Display all metadata for all messages stored in a single mailbox
* Convert messages to text using Google's speech-to-text service
* Retrieve the audio of a message in MP3 format
* Support both synchronous and asynchronous API

Future work
============

* Support deleting messages
* Support moving messages
* Support multiple mailboxes
* Support alternate text-to-speech providers
